package core.entities.timemanager;

import core.api.models.timemanager.taskSchedule.BasicScheduleInfo;
import core.api.models.timemanager.taskSchedule.ScheduleInfo;
import core.api.models.timemanager.taskSchedule.ScheduleType;
import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;
import core.api.models.timemanager.tasks.TaskEntityInfo;

import javax.persistence.*;
import java.time.Duration;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Objects;

@Entity
@DiscriminatorValue("0")
public class BasicTaskSchedule extends AbstractSchedule{

   private LocalDate scheduleDate;

    public BasicTaskSchedule() {
    }

    public BasicTaskSchedule(Task task, LocalDateTime startTime, LocalDateTime stopTime, LocalDate scheduleDate) {
        super(task, startTime, stopTime);
        this.scheduleDate = scheduleDate;
    }

    public BasicTaskSchedule(Task task, LocalDate scheduleDate) {
        super(task);
        this.scheduleDate = scheduleDate;
    }

    public LocalDate getScheduleDate() {
        return scheduleDate;
    }

    public void setScheduleDate(LocalDate scheduleDate) {
        this.scheduleDate = scheduleDate;
    }

    public ScheduleInfo toScheduleInfo() {
        int activeMinutes = calcActiveMinutes();
        List<TaskgroupEntityInfo> taskgroupEntityInfos = Taskgroup.getAncestorList(task.getTaskgroup()).stream().map(TaskgroupEntityInfo::new).toList();
        return new BasicScheduleInfo(scheduleID, ScheduleType.BASIC, startTime, stopTime, activeMinutes, task, taskgroupEntityInfos);
    }

    public int calcActiveMinutes() {
        if(startTime == null) {
            return 0;
        } else if(stopTime == null) {
            Duration duration = Duration.between(startTime, LocalDateTime.now());
            return (int) duration.toMinutes();
        } else {
            Duration duration = Duration.between(startTime, stopTime);
            return (int) duration.toMinutes();
        }
    }
}
